﻿local L = AceLibrary("AceLocale-2.2"):new("GridStatusAFK")

L:RegisterTranslations("enUS", function() return {
	["AFK"] = true,
	["<AFK>"] = true,
	["AFK alert"] = true,
} end)

L:RegisterTranslations("deDE", function() return {
	["AFK"] = "AFK",
	["<AFK>"] = "<AFK>",
	["AFK alert"] = "AFK Alarm",
} end)

L:RegisterTranslations("koKR", function() return {
	["AFK"] = "자리비움",
	["<AFK>"] = "<자리비움>",
	["AFK alert"] = "자리비움 경고",
} end)

L:RegisterTranslations("zhTW", function() return {
	["AFK"] = "暫離",
	["<AFK>"] = "<暫離>",
	["AFK alert"] = "暫離警告",
} end)

L:RegisterTranslations("zhCN", function() return {
	["AFK"] = "暂离",
	["<AFK>"] = "<暂离>",
	["AFK alert"] = "暂离警告",
} end)


GridStatusAFK = GridStatus:NewModule("GridStatusAFK")
local GridStatusAFK = GridStatusAFK
GridStatusAFK.menuName = L["AFK"]
GridStatusAFK.options = false

GridStatusAFK.defaultDB = {
	debug = false,
	alert_afk = {
		text =  L["<AFK>"],
		enable = false,
		color = { r = 0.5, g = 0.5, b = 0.5, a = 0.5 },
		priority = 20,
		range = false,
	},
}


function GridStatusAFK:OnInitialize()
	self.super.OnInitialize(self)

	self:RegisterStatus("alert_afk", L["AFK alert"], nil, true)
end

function GridStatusAFK:OnEnable()
	self.debugging = self.db.profile.debug
	self:Debug("OnEnable")

	self.super.OnEnable(self)
end

function GridStatusAFK:Reset()
	self.super.Reset(self)

	self.core:SendStatusLostAllUnits(status)
	self:UnregisterStatus("alert_afk")
	self:RegisterStatus("alert_afk", L["AFK alert"], nil, true)

	self:ZONE_CHANGED_NEW_AREA()
	self:UpdateAllUnits()
end


function GridStatusAFK:OnStatusEnable(status)
	self:RegisterEvent("PLAYER_FLAGS_CHANGED", "UpdateUnit")
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	self:RegisterEvent("Grid_UnitJoined")
	self:RegisterEvent("Grid_UnitOffline")

	self:ZONE_CHANGED_NEW_AREA()
	self:UpdateAllUnits()
end

function GridStatusAFK:OnStatusDisable(status)
	self.core:SendStatusLostAllUnits(status)

	self:UnregisterEvent("PLAYER_FLAGS_CHANGED")
	self:UnregisterEvent("ZONE_CHANGED_NEW_AREA")
	self:UnregisterEvent("Grid_UnitJoined")
	self:UnregisterEvent("Grid_UnitOffline")
end


local instanceType
function GridStatusAFK:ZONE_CHANGED_NEW_AREA()
	instanceType = select(2, IsInInstance())
	if instanceType == "pvp" or instanceType == "arena" then
		self.core:SendStatusLost(UnitGUID("player"), "alert_afk")
	else
		instanceType = nil
	end
end

function GridStatusAFK:UpdateAllUnits()
	if (self.db.profile.alert_afk.enable) then
		for guid, unitid in GridRoster:IterateRoster() do
			self:UpdateUnit(unitid)
		end
	end
end

function GridStatusAFK:UpdateUnit(unitid)
	if (instanceType) then
		return
	end
	if (string.find(unitid, "pet")) then
		return
	end
	local guid = UnitGUID(unitid)
	if (not GridRoster:IsGUIDInRaid(guid)) then
		return
	end

	if (UnitIsAFK(unitid)) then
		local settings = self.db.profile.alert_afk
		self.core:SendStatusGained(guid, "alert_afk",
						settings.priority,
						(settings.range and 40),
						settings.color,
						settings.text,
						nil,
						nil,
						settings.icon)
	else
		self.core:SendStatusLost(guid, "alert_afk")
	end
end

function GridStatusAFK:Grid_UnitJoined(guid, unitid)
	self:UpdateUnit(unitid)
end

function GridStatusAFK:Grid_UnitOffline(guid)
	self.core:SendStatusLost(guid, "alert_afk")
end
